==> igniteui-webcomponents-core-3.2.2.tgz: package/esm5/lib/HeatTileGeneratorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HeatTileGeneratorDescription } from "./HeatTileGeneratorDescription";
/**
 * @hidden
 */
var HeatTileGeneratorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(HeatTileGeneratorDescriptionMetadata, _super);
    function HeatTileGeneratorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    HeatTileGeneratorDescriptionMetadata.b = function (a) {
        if (HeatTileGeneratorDescriptionMetadata.a == null) {
            HeatTileGeneratorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            HeatTileGeneratorDescriptionMetadata.c(HeatTileGeneratorDescriptionMetadata.a);
        }
        if (a.g(HeatTileGeneratorDescriptionMetadata.a)) {
            return;
        }
        a.s(HeatTileGeneratorDescriptionMetadata.a);
    };
    HeatTileGeneratorDescriptionMetadata.c = function (a) {
        a.item("YValues", "Array:double");
        a.item("XValues", "Array:double");
        a.item("Values", "Array:double");
        a.item("MinimumColor", "Color");
        a.item("MaximumColor", "Color");
        a.item("ScaleColors", "Array:string:Color");
        a.item("ScaleColorOffsets", "Array:double");
        a.item("BlurRadius", "Number:double");
        a.item("MaxBlurRadius", "Number:double");
        a.item("UseBlurRadiusAdjustedForZoom", "Boolean");
        a.item("UseGlobalMinMax", "Boolean");
        a.item("UseGlobalMinMaxAdjustedForZoom", "Boolean");
        a.item("MinimumValue", "Number:double");
        a.item("MaximumValue", "Number:double");
        a.item("LogarithmBase", "Number:double");
        a.item("UseLogarithmicScale", "Boolean");
        a.item("UseWebWorkers", "Boolean");
        a.item("WebWorkerScriptPath", "String");
        a.item("WebWorkerInstanceRef", "(w:WebWorkerInstance,wf:WebWorkerInstance)DataRef");
    };
    HeatTileGeneratorDescriptionMetadata.d = function (a) {
        HeatTileGeneratorDescriptionMetadata.b(a);
        a.u("HeatTileGenerator", function () { return new HeatTileGeneratorDescription(); });
        a.t("HeatTileGenerator", HeatTileGeneratorDescriptionMetadata.a);
    };
    HeatTileGeneratorDescriptionMetadata.$t = markType(HeatTileGeneratorDescriptionMetadata, 'HeatTileGeneratorDescriptionMetadata');
    HeatTileGeneratorDescriptionMetadata.a = null;
    return HeatTileGeneratorDescriptionMetadata;
}(Base));
export { HeatTileGeneratorDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/HeatTileGeneratorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HeatTileGeneratorDescription } from "./HeatTileGeneratorDescription";
/**
 * @hidden
 */
var HeatTileGeneratorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(HeatTileGeneratorDescriptionMetadata, _super);
    function HeatTileGeneratorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    HeatTileGeneratorDescriptionMetadata.b = function (a) {
        if (HeatTileGeneratorDescriptionMetadata.a == null) {
            HeatTileGeneratorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            HeatTileGeneratorDescriptionMetadata.c(HeatTileGeneratorDescriptionMetadata.a);
        }
        if (a.j(HeatTileGeneratorDescriptionMetadata.a)) {
            return;
        }
        a.y(HeatTileGeneratorDescriptionMetadata.a);
    };
    HeatTileGeneratorDescriptionMetadata.c = function (a) {
        a.item("YValues", "Array:double");
        a.item("XValues", "Array:double");
        a.item("Values", "Array:double");
        a.item("MinimumColor", "Color");
        a.item("MaximumColor", "Color");
        a.item("ScaleColors", "Array:string:Color");
        a.item("ScaleColorOffsets", "Array:double");
        a.item("BlurRadius", "Number:double");
        a.item("MaxBlurRadius", "Number:double");
        a.item("UseBlurRadiusAdjustedForZoom", "Boolean");
        a.item("UseGlobalMinMax", "Boolean");
        a.item("UseGlobalMinMaxAdjustedForZoom", "Boolean");
        a.item("MinimumValue", "Number:double");
        a.item("MaximumValue", "Number:double");
        a.item("LogarithmBase", "Number:double");
        a.item("UseLogarithmicScale", "Boolean");
        a.item("UseWebWorkers", "Boolean");
        a.item("WebWorkerScriptPath", "String");
        a.item("WebWorkerInstanceRef", "(w:WebWorkerInstance,wf:WebWorkerInstance)DataRef");
    };
    HeatTileGeneratorDescriptionMetadata.d = function (a) {
        HeatTileGeneratorDescriptionMetadata.b(a);
        a.aa("HeatTileGenerator", function () { return new HeatTileGeneratorDescription(); });
        a.z("HeatTileGenerator", HeatTileGeneratorDescriptionMetadata.a);
    };
    HeatTileGeneratorDescriptionMetadata.$t = markType(HeatTileGeneratorDescriptionMetadata, 'HeatTileGeneratorDescriptionMetadata');
    HeatTileGeneratorDescriptionMetadata.a = null;
    return HeatTileGeneratorDescriptionMetadata;
}(Base));
export { HeatTileGeneratorDescriptionMetadata };
